@@ -1,8 +1,8 @@
-/// Assert a command stdout string is equal to another.
+/// Assert a command stdout string is equal to an expression.
 ///
-/// * When true, return `()`.
+/// * If true, return Result `Ok(())`.
 ///
-/// * When true, return Result `Err` with a diagnostic message.
+/// * Otherwise, return Result `Err` with a diagnostic message.
 ///
 /// # Examples
 ///
@@ -29,10 +29,10 @@
 /// let actual = x.unwrap_err();
 /// let expect = concat!(
 ///     "assertion failed: `assert_command_stdout_eq!(left_command, right_expr)`\n",
-///     "  left command name: `command`,\n",
-///     "    right expr name: `s`,\n",
-///     "       left command: `\"printf\"`,\n",
-///     "         right expr: `\"world\"`,\n",
+///     " left_command label: `command`,\n",
+///     " left_command debug: `\"printf\" \"%s\" \"hello\"`,\n",
+///     "   right_expr label: `s`,\n",
+///     "   right_expr debug: `\"world\"`,\n",
 ///     "               left: `\"hello\"`,\n",
 ///     "              right: `\"world\"`"
 /// );
@@ -45,31 +45,38 @@ macro_rules! assert_command_stdout_eq_as_result {
     ($a_command:expr, $b_expr:expr $(,)?) => ({
         let a_output = $a_command.output();
         if a_output.is_err() {
-            Err(msg_with_left_command_and_right_expr!(
-                "assertion failed",
-                "assert_command_stdout_eq!",
-                stringify!($a_command),
-                stringify!($b_expr),
-                $a_command.get_program(),
-                $b_expr,
-                a_output,
-                $b_expr
+            Err(format!(
+                concat!(
+                    "assertion failed: `assert_command_stdout_eq!(left_command, right_expr)`\n",
+                    " left_command label: `{}`,\n",
+                    " left_command debug: `{:?}`,\n",
+                    "   right_expr label: `{}`,\n",
+                    "   right_expr debug: `{:?}`,\n",
+                    "        left output: `{:?}`"
+                ),
+                stringify!($a_command), $a_command,
+                stringify!($b_expr), $b_expr,
+                a_output
             ))
         } else {
             let a_string = String::from_utf8(a_output.unwrap().stdout).unwrap();
-            let b_string = String::from($b_expr);
-            if a_string == b_string {
+            if a_string == $b_expr {
                 Ok(())
             } else {
-                Err(msg_with_left_command_and_right_expr!(
-                    "assertion failed",
-                    "assert_command_stdout_eq!",
-                    stringify!($a_command),
-                    stringify!($b_expr),
-                    $a_command.get_program(),
-                    $b_expr,
+                Err(format!(
+                    concat!(
+                        "assertion failed: `assert_command_stdout_eq!(left_command, right_expr)`\n",
+                        " left_command label: `{}`,\n",
+                        " left_command debug: `{:?}`,\n",
+                        "   right_expr label: `{}`,\n",
+                        "   right_expr debug: `{:?}`,\n",
+                        "               left: `{:?}`,\n",
+                        "              right: `{:?}`"
+                    ),
+                    stringify!($a_command), $a_command,
+                    stringify!($b_expr), $b_expr,
                     a_string,
-                    b_string
+                    $b_expr
                 ))
             }
         }
@@ -99,10 +106,10 @@ mod test_x_result {
         let actual = x.unwrap_err();
         let expect = concat!(
           "assertion failed: `assert_command_stdout_eq!(left_command, right_expr)`\n",
-          "  left command name: `a`,\n",
-          "    right expr name: `b`,\n",
-          "       left command: `\"printf\"`,\n",
-          "         right expr: `\"bravo\"`,\n",
+          " left_command label: `a`,\n",
+          " left_command debug: `\"printf\" \"%s\" \"alpha\"`,\n",
+          "   right_expr label: `b`,\n",
+          "   right_expr debug: `\"bravo\"`,\n",
           "               left: `\"alpha\"`,\n",
           "              right: `\"bravo\"`"
         );
@@ -110,9 +117,9 @@ mod test_x_result {
     }
 }
 
-/// Assert a command stdout string is equal to another.
+/// Assert a command stdout string is equal to an expression.
 ///
-/// * When true, return `()`.
+/// * If true, return `()`.
 ///
 /// * Otherwise, call [`panic!`] with a message and the values of the
 ///   expressions with their debug representations.
@@ -141,10 +148,10 @@ mod test_x_result {
 /// let actual = result.unwrap_err().downcast::<String>().unwrap().to_string();
 /// let expect = concat!(
 ///     "assertion failed: `assert_command_stdout_eq!(left_command, right_expr)`\n",
-///     "  left command name: `command`,\n",
-///     "    right expr name: `s`,\n",
-///     "       left command: `\"printf\"`,\n",
-///     "         right expr: `\"world\"`,\n",
+///     " left_command label: `command`,\n",
+///     " left_command debug: `\"printf\" \"%s\" \"hello\"`,\n",
+///     "   right_expr label: `s`,\n",
+///     "   right_expr debug: `\"world\"`,\n",
 ///     "               left: `\"hello\"`,\n",
 ///     "              right: `\"world\"`"
 /// );
@@ -167,46 +174,3 @@ macro_rules! assert_command_stdout_eq {
         }
     });
 }
-
-#[cfg(test)]
-mod test_x_panic {
-
-    use std::process::Command;
-
-    #[test]
-    fn test_assert_command_stdout_eq_x_arity_2_success() {
-        let mut a = Command::new("printf");
-        a.args(["%s", "alpha"]);
-        let b = "alpha";
-        let x = assert_command_stdout_eq!(a, b);
-        assert_eq!(x, ());
-    }
-
-    #[test]
-    #[should_panic (expected = "assertion failed: `assert_command_stdout_eq!(left_command, right_expr)`\n  left command name: `a`,\n    right expr name: `b`,\n       left command: `\"printf\"`,\n         right expr: `\"bravo\"`,\n               left: `\"alpha\"`,\n              right: `\"bravo\"`")]
-    fn test_assert_command_stdout_eq_x_arity_2_failure() {
-        let mut a = Command::new("printf");
-        a.args(["%s", "alpha"]);
-        let b = "bravo";
-        let _x = assert_command_stdout_eq!(a, b);
-    }
-
-    #[test]
-    fn test_assert_command_stdout_eq_x_arity_3_success() {
-        let mut a = Command::new("printf");
-        a.args(["%s", "alpha"]);
-        let b = "alpha";
-        let x = assert_command_stdout_eq!(a, b, "message");
-        assert_eq!(x, ());
-    }
-
-    #[test]
-    #[should_panic (expected = "message")]
-    fn test_assert_command_stdout_eq_x_arity_3_failure() {
-        let mut a = Command::new("printf");
-        a.args(["%s", "alpha"]);
-        let b = "bravo";
-        let _x = assert_command_stdout_eq!(a, b, "message");
-    }
-
-}
