@@ -1,8 +1,8 @@
 /// Assert a function output is equal to a given.
 ///
-/// * When true, return Result `Ok(())`.
+/// * If true, return Result `Ok(())`.
 ///
-/// * When true, return Result `Err` with a diagnostic message.
+/// * Otherwise, return Result `Err` with a diagnostic message.
 ///
 /// # Examples
 ///
@@ -22,15 +22,14 @@
 /// //-> Err(…)
 /// let actual = x.unwrap_err();
 /// let expect = concat!(
-///     "assertion failed: `assert_fn_eq!(function, left_input, right_expr)`\n",
-///     "    function name: `i32::abs`,\n",
-///     "  left input name: `a`,\n",
-///     "  right expr name: `b`,\n",
-///     "       left input: `-1`,\n",
-///     "       right expr: `2`,\n",
-///     "      left output: `1`,\n",
-///     "             left: `1`,\n",
-///     "            right: `2`"
+///     "assertion failed: `assert_fn_eq!(left_function, left_input, right_expr)`\n",
+///     " left_function label: `i32::abs`,\n",
+///     "    left_input label: `a`,\n",
+///     "    left_input debug: `-1`,\n",
+///     "    right_expr label: `b`,\n",
+///     "    right_expr debug: `2`,\n",
+///     "                left: `1`,\n",
+///     "               right: `2`"
 /// );
 /// assert_eq!(actual, expect);
 /// # }
@@ -47,15 +46,22 @@ macro_rules! assert_fn_eq_as_result {
             if a_output == $b_expr {
                 Ok(())
             } else {
-                Err(msg_with_left_function_and_left_input_and_right_expr!(
-                    "assertion failed",
-                    "assert_fn_eq!",
+                Err(format!(
+                    concat!(
+                        "assertion failed: `assert_fn_eq!(left_function, left_input, right_expr)`\n",
+                        " left_function label: `{}`,\n",
+                        "    left_input label: `{}`,\n",
+                        "    left_input debug: `{:?}`,\n",
+                        "    right_expr label: `{}`,\n",
+                        "    right_expr debug: `{:?}`,\n",
+                        "                left: `{:?}`,\n",
+                        "               right: `{:?}`"
+                    ),
                     stringify!($function),
-                    stringify!($a_input),
-                    stringify!($b_expr),
-                    $a_input,
-                    $b_expr,
-                    a_output
+                    stringify!($a_input), $a_input,
+                    stringify!($b_expr), $b_expr,
+                    a_output,
+                    $b_expr
                 ))
             }
         }
@@ -81,15 +87,14 @@ mod test_x_result {
         assert_eq!(
             x.unwrap_err(),
             concat!(
-                "assertion failed: `assert_fn_eq!(function, left_input, right_expr)`\n",
-                "    function name: `i32::abs`,\n",
-                "  left input name: `a`,\n",
-                "  right expr name: `b`,\n",
-                "       left input: `-1`,\n",
-                "       right expr: `2`,\n",
-                "      left output: `1`,\n",
-                "             left: `1`,\n",
-                "            right: `2`"
+                "assertion failed: `assert_fn_eq!(left_function, left_input, right_expr)`\n",
+                " left_function label: `i32::abs`,\n",
+                "    left_input label: `a`,\n",
+                "    left_input debug: `-1`,\n",
+                "    right_expr label: `b`,\n",
+                "    right_expr debug: `2`,\n",
+                "                left: `1`,\n",
+                "               right: `2`"
             )
         );
     }
@@ -97,7 +102,7 @@ mod test_x_result {
 
 /// Assert a function output is equal to a given value.
 ///
-/// * When true, return `()`.
+/// * If true, return `()`.
 ///
 /// * Otherwise, call [`panic!`] with a message and the values of the
 ///   expressions with their debug representations.
@@ -121,15 +126,14 @@ mod test_x_result {
 /// });
 /// let actual = result.unwrap_err().downcast::<String>().unwrap().to_string();
 /// let expect = concat!(
-///     "assertion failed: `assert_fn_eq!(function, left_input, right_expr)`\n",
-///     "    function name: `i32::abs`,\n",
-///     "  left input name: `a`,\n",
-///     "  right expr name: `b`,\n",
-///     "       left input: `-1`,\n",
-///     "       right expr: `2`,\n",
-///     "      left output: `1`,\n",
-///     "             left: `1`,\n",
-///     "            right: `2`"
+///     "assertion failed: `assert_fn_eq!(left_function, left_input, right_expr)`\n",
+///     " left_function label: `i32::abs`,\n",
+///     "    left_input label: `a`,\n",
+///     "    left_input debug: `-1`,\n",
+///     "    right_expr label: `b`,\n",
+///     "    right_expr debug: `2`,\n",
+///     "                left: `1`,\n",
+///     "               right: `2`"
 /// );
 /// assert_eq!(actual, expect);
 /// # }
@@ -150,40 +154,3 @@ macro_rules! assert_fn_eq {
         }
     });
 }
-
-#[cfg(test)]
-mod test_x_panic {
-
-    #[test]
-    fn test_assert_fn_eq_x_arity_2_eq_success() {
-        let a: i32 = -1;
-        let b: i32 = 1;
-        let x = assert_fn_eq!(i32::abs, a, b);
-        assert_eq!(x, ());
-    }
-
-    #[test]
-    #[should_panic (expected = "assertion failed: `assert_fn_eq!(function, left_input, right_expr)`\n    function name: `i32::abs`,\n  left input name: `a`,\n  right expr name: `b`,\n       left input: `-1`,\n       right expr: `2`,\n      left output: `1`,\n             left: `1`,\n            right: `2`")]
-    fn test_assert_fn_eq_x_arity_2_ne_failure() {
-        let a: i32 = -1;
-        let b: i32 = 2;
-        let _x = assert_fn_eq!(i32::abs, a, b);
-    }
-
-    #[test]
-    fn test_assert_fn_eq_x_arity_3_eq_success() {
-        let a: i32 = -1;
-        let b: i32 = 1;
-        let x = assert_fn_eq!(i32::abs, a, b, "message");
-        assert_eq!(x, ());
-    }
-
-    #[test]
-    #[should_panic (expected = "message")]
-    fn test_assert_fn_eq_x_arity_3_ne_failure() {
-        let a: i32 = -1;
-        let b: i32 = 2;
-        let _x = assert_fn_eq!(i32::abs, a, b, "message");
-    }
-
-}
