@@ -1,8 +1,8 @@
 /// Assert one function ok() is less than or equal to another function ok().
 ///
-/// * When true, return Result `Ok(())`.
+/// * If true, return Result `Ok(())`.
 ///
-/// * When true, return Result `Err` with a diagnostic message.
+/// * Otherwise, return Result `Err` with a diagnostic message.
 ///
 /// # Examples
 ///
@@ -32,15 +32,14 @@
 
 /// let actual = x.unwrap_err();
 /// let expect = concat!(
-///     "assertion failed: `assert_fn_ok_le!(function, left_input, right_expr)`\n",
-///     "    function name: `example_digit_to_string`,\n",
-///     "  left input name: `a`,\n",
-///     "  right expr name: `b`,\n",
-///     "       left input: `2`,\n",
-///     "       right expr: `\"1\"`,\n",
-///     "      left output: `\"2\"`,\n",
-///     "             left: `\"2\"`,\n",
-///     "            right: `\"1\"`"
+///     "assertion failed: `assert_fn_ok_le!(left_function, left_input, right_expr)`\n",
+///     " left_function label: `example_digit_to_string`,\n",
+///     "    left_input label: `a`,\n",
+///     "    left_input debug: `2`,\n",
+///     "    right_expr label: `b`,\n",
+///     "    right_expr debug: `\"1\"`,\n",
+///     "                left: `\"2\"`,\n",
+///     "               right: `\"1\"`"
 /// );
 /// # }
 /// ```
@@ -51,14 +50,19 @@ macro_rules! assert_fn_ok_le_as_result {
         let a_result = $function($a_input);
         let a_is_ok = a_result.is_ok();
         if !a_is_ok {
-            Err(msg_with_left_function_and_left_input_and_right_expr!(
-                "assertion failed",
-                "assert_fn_ok_le!",
+            Err(format!(
+                concat!(
+                    "assertion failed: `assert_fn_ok_le!(left_function, left_input, right_expr)`\n",
+                    " left_function label: `{}`,\n",
+                    "    left_input label: `{}`,\n",
+                    "    left_input debug: `{:?}`,\n",
+                    "    right_expr label: `{}`,\n",
+                    "    right_expr debug: `{:?}`,\n",
+                    "         left result: `{:?}`",
+                ),
                 stringify!($function),
-                stringify!($a_input),
-                stringify!($b_expr),
-                $a_input,
-                $b_expr,
+                stringify!($a_input), $a_input,
+                stringify!($b_expr), $b_expr,
                 a_result
             ))
         } else {
@@ -66,15 +70,22 @@ macro_rules! assert_fn_ok_le_as_result {
             if a_ok <= $b_expr {
                 Ok(())
             } else {
-                Err(msg_with_left_function_and_left_input_and_right_expr!(
-                    "assertion failed",
-                    "assert_fn_ok_le!",
+                Err(format!(
+                    concat!(
+                        "assertion failed: `assert_fn_ok_le!(left_function, left_input, right_expr)`\n",
+                        " left_function label: `{}`,\n",
+                        "    left_input label: `{}`,\n",
+                        "    left_input debug: `{:?}`,\n",
+                        "    right_expr label: `{}`,\n",
+                        "    right_expr debug: `{:?}`,\n",
+                        "                left: `{:?}`,\n",
+                        "               right: `{:?}`",
+                    ),
                     stringify!($function),
-                    stringify!($a_input),
-                    stringify!($b_expr),
-                    $a_input,
-                    $b_expr,
-                    a_ok
+                    stringify!($a_input), $a_input,
+                    stringify!($b_expr), $b_expr,
+                    a_ok,
+                    $b_expr
                 ))
             }
         }
@@ -121,15 +132,14 @@ mod test_x_result {
         assert_eq!(
             x.unwrap_err(),
             concat!(
-                "assertion failed: `assert_fn_ok_le!(function, left_input, right_expr)`\n",
-                "    function name: `example_digit_to_string`,\n",
-                "  left input name: `a`,\n",
-                "  right expr name: `b`,\n",
-                "       left input: `2`,\n",
-                "       right expr: `\"1\"`,\n",
-                "      left output: `\"2\"`,\n",
-                "             left: `\"2\"`,\n",
-                "            right: `\"1\"`"
+                "assertion failed: `assert_fn_ok_le!(left_function, left_input, right_expr)`\n",
+                " left_function label: `example_digit_to_string`,\n",
+                "    left_input label: `a`,\n",
+                "    left_input debug: `2`,\n",
+                "    right_expr label: `b`,\n",
+                "    right_expr debug: `\"1\"`,\n",
+                "                left: `\"2\"`,\n",
+                "               right: `\"1\"`"
             )
         );
     }
@@ -137,7 +147,7 @@ mod test_x_result {
 
 /// Assert a function ok() is less than or equal to another.
 ///
-/// * When true, return `()`.
+/// * If true, return `()`.
 ///
 /// * Otherwise, call [`panic!`] with a message and the values of the
 ///   expressions with their debug representations.
@@ -169,15 +179,14 @@ mod test_x_result {
 /// });
 /// let actual = result.unwrap_err().downcast::<String>().unwrap().to_string();
 /// let expect = concat!(
-///     "assertion failed: `assert_fn_ok_le!(function, left_input, right_expr)`\n",
-///     "    function name: `example_digit_to_string`,\n",
-///     "  left input name: `a`,\n",
-///     "  right expr name: `b`,\n",
-///     "       left input: `2`,\n",
-///     "       right expr: `\"1\"`,\n",
-///     "      left output: `\"2\"`,\n",
-///     "             left: `\"2\"`,\n",
-///     "            right: `\"1\"`"
+///     "assertion failed: `assert_fn_ok_le!(left_function, left_input, right_expr)`\n",
+///     " left_function label: `example_digit_to_string`,\n",
+///     "    left_input label: `a`,\n",
+///     "    left_input debug: `2`,\n",
+///     "    right_expr label: `b`,\n",
+///     "    right_expr debug: `\"1\"`,\n",
+///     "                left: `\"2\"`,\n",
+///     "               right: `\"1\"`"
 /// );
 /// assert_eq!(actual, expect);
 /// # }
@@ -198,63 +207,3 @@ macro_rules! assert_fn_ok_le {
         }
     });
 }
-
-#[cfg(test)]
-mod test_x_panic {
-
-    fn example_digit_to_string(i: i32) -> Result<String, String> {
-        match i {
-            0..=9 => Ok(format!("{}", i)),
-            _ => Err(format!("{:?} is out of range", i)),
-        }
-    }
-
-    #[test]
-    fn test_assert_fn_ok_le_x_arity_2_lt_success() {
-        let a: i32 = 1;
-        let b = String::from("2");
-        let x = assert_fn_ok_le!(example_digit_to_string, a, b);
-        assert_eq!(x, ());
-    }
-
-    #[test]
-    fn test_assert_fn_ok_le_x_arity_2_eq_success() {
-        let a: i32 = 1;
-        let b = String::from("1");
-        let x = assert_fn_ok_le!(example_digit_to_string, a, b);
-        assert_eq!(x, ());
-    }
-
-    #[test]
-    #[should_panic (expected = "assertion failed: `assert_fn_ok_le!(function, left_input, right_expr)`\n    function name: `example_digit_to_string`,\n  left input name: `a`,\n  right expr name: `b`,\n       left input: `2`,\n       right expr: `\"1\"`,\n      left output: `\"2\"`,\n             left: `\"2\"`,\n            right: `\"1\"`")]
-    fn test_assert_fn_ok_le_x_arity_2_gt_failure() {
-        let a: i32 = 2;
-        let b = String::from("1");
-        let _x = assert_fn_ok_le!(example_digit_to_string, a, b);
-    }
-
-    #[test]
-    fn test_assert_fn_ok_le_x_arity_3_lt_success() {
-        let a: i32 = 1;
-        let b = String::from("2");
-        let x = assert_fn_ok_le!(example_digit_to_string, a, b, "message");
-        assert_eq!(x, ());
-    }
-
-    #[test]
-    fn test_assert_fn_ok_le_x_arity_3_eq_success() {
-        let a: i32 = 1;
-        let b = String::from("1");
-        let x = assert_fn_ok_le!(example_digit_to_string, a, b, "message");
-        assert_eq!(x, ());
-    }
-
-    #[test]
-    #[should_panic (expected = "message")]
-    fn test_assert_fn_ok_le_x_arity_3_failure() {
-        let a: i32 = 2;
-        let b = String::from("1");
-        let _x = assert_fn_ok_le!(example_digit_to_string, a, b, "message");
-    }
-
-}
