@@ -1,8 +1,8 @@
 /// Assert one value is greater than another.
 ///
-/// * When true, return Result `Ok(())`.
+/// * If true, return Result `Ok(())`.
 ///
-/// * When true, return Result `Err` with a diagnostic message.
+/// * Otherwise, return Result `Err` with a diagnostic message.
 ///
 /// # Examples
 ///
@@ -10,19 +10,27 @@
 /// # #[macro_use] extern crate assertables;
 /// # use std::panic;
 /// # fn main() {
-/// let x = assert_gt_as_result!(2, 1);
+/// let a = 2;
+/// let b = 1;
+/// let x = assert_gt_as_result!(a, b);
 /// //-> Ok(())
 /// let actual = x.unwrap();
 /// let expect = ();
 /// assert_eq!(actual, expect);
 ///
-/// let x = assert_gt_as_result!(1, 2);
+/// let a = 1;
+/// let b = 2;
+/// let x = assert_gt_as_result!(a, b);
 /// //-> Err(…)
 /// let actual = x.unwrap_err();
 /// let expect = concat!(
 ///     "assertion failed: `assert_gt!(left, right)`\n",
-///     "  left: `1`,\n",
-///     " right: `2`"
+///     "  left label: `a`,\n",
+///     "  left debug: `1`,\n",
+///     " right label: `b`,\n",
+///     " right debug: `2`,\n",
+///     "        left: `1`,\n",
+///     "       right: `2`"
 /// );
 /// assert_eq!(actual, expect);
 /// # }
@@ -36,7 +44,21 @@ macro_rules! assert_gt_as_result {
                 if a_val > b_val {
                     Ok(())
                 } else {
-                    Err(msg_with_left_and_right!("assertion failed", "assert_gt!", a_val, b_val))
+                    Err(format!(
+                        concat!(
+                            "assertion failed: `assert_gt!(left, right)`\n",
+                            "  left label: `{}`,\n",
+                            "  left debug: `{:?}`,\n",
+                            " right label: `{}`,\n",
+                            " right debug: `{:?}`,\n",
+                            "        left: `{:?}`,\n",
+                            "       right: `{:?}`"
+                        ),
+                        stringify!($a), $a,
+                        stringify!($b), $b,
+                        a_val, 
+                        b_val
+                    ))
                 }
             }
         }
@@ -66,8 +88,12 @@ mod test_x_result {
             x.unwrap_err(),
             concat!(
                 "assertion failed: `assert_gt!(left, right)`\n",
-                "  left: `1`,\n",
-                " right: `2`"
+                "  left label: `a`,\n",
+                "  left debug: `1`,\n",
+                " right label: `b`,\n",
+                " right debug: `2`,\n",
+                "        left: `1`,\n",
+                "       right: `2`"
             )
         );
     }
@@ -75,7 +101,7 @@ mod test_x_result {
 
 /// Assert a value is greater than another.
 ///
-/// * When true, return `()`.
+/// * If true, return `()`.
 ///
 /// * Otherwise, call [`panic!`] with a message and the values of the
 ///   expressions with their debug representations.
@@ -86,18 +112,26 @@ mod test_x_result {
 /// # #[macro_use] extern crate assertables;
 /// # use std::panic;
 /// # fn main() {
-/// assert_gt!(2, 1);
+/// let a = 2;
+/// let b = 1;
+/// assert_gt!(a, b);
 /// //-> ()
 ///
 /// let result = panic::catch_unwind(|| {
-/// assert_gt!(1, 2);
+/// let a = 1;
+/// let b = 2;
+/// assert_gt!(a, b);
 /// //-> panic!
 /// });
 /// let actual = result.unwrap_err().downcast::<String>().unwrap().to_string();
 /// let expect = concat!(
 ///     "assertion failed: `assert_gt!(left, right)`\n",
-///     "  left: `1`,\n",
-///     " right: `2`"
+///     "  left label: `a`,\n",
+///     "  left debug: `1`,\n",
+///     " right label: `b`,\n",
+///     " right debug: `2`,\n",
+///     "        left: `1`,\n",
+///     "       right: `2`"
 /// );
 /// assert_eq!(actual, expect);
 /// # }
@@ -106,62 +140,15 @@ mod test_x_result {
 #[macro_export]
 macro_rules! assert_gt {
     ($a:expr, $b:expr $(,)?) => ({
-        match (&$a, &$b) {
-            (a_val, b_val) => {
-                if a_val > b_val {
-                    ()
-                } else {
-                    panic!("{}", msg_with_left_and_right!("assertion failed", "assert_gt!", $a, $b))
-                }
-            }
+        match assert_gt_as_result!($a, $b) {
+            Ok(()) => (),
+            Err(err) => panic!("{}", err),
         }
     });
     ($a:expr, $b:expr, $($arg:tt)+) => ({
-        match (&($a), &($b)) {
-            (a_val, b_val) => {
-                if a_val > b_val {
-                    ()
-                } else {
-                    panic!("{:?}", $($arg)+)
-                }
-            }
+        match assert_gt_as_result!($a, $b) {
+            Ok(()) => (),
+            Err(_err) => panic!($($arg)+),
         }
     });
 }
-
-#[cfg(test)]
-mod test_x_panic {
-
-    #[test]
-    fn test_assert_gt_x_arity_2_success() {
-        let a: i32 = 2;
-        let b: i32 = 1;
-        let x = assert_gt!(a, b);
-        assert_eq!(x, ());
-    }
-
-    #[test]
-    #[should_panic (expected = "assertion failed: `assert_gt!(left, right)`\n  left: `1`,\n right: `2`")]
-    fn test_assert_gt_x_arity_2_failure() {
-        let a: i32 = 1;
-        let b: i32 = 2;
-        let _x = assert_gt!(a, b);
-    }
-
-    #[test]
-    fn test_assert_gt_x_arity_3_success() {
-        let a: i32 = 2;
-        let b: i32 = 1;
-        let x = assert_gt!(a, b, "message");
-        assert_eq!(x, ());
-    }
-
-    #[test]
-    #[should_panic (expected = "message")]
-    fn test_assert_gt_x_arity_3_failure() {
-        let a: i32 = 1;
-        let b: i32 = 2;
-        let _x = assert_gt!(a, b, "message");
-    }
-
-}
