@@ -1,6 +1,6 @@
 /// Assert one value is less than another.
 ///
-/// * When true, return `Ok(())`.
+/// * If true, return `Ok(())`.
 ///
 /// * Otherwise, return [`Err`] with a message and the values of the
 ///   expressions with their debug representations.
@@ -11,19 +11,27 @@
 /// # #[macro_use] extern crate assertables;
 /// # use std::panic;
 /// # fn main() {
-/// let x = assert_lt_as_result!(1, 2);
+/// let a = 1;
+/// let b = 2;
+/// let x = assert_lt_as_result!(a, b);
 /// //-> Ok(())
 /// let actual = x.unwrap();
 /// let expect = ();
 /// assert_eq!(actual, expect);
 ///
-/// let x = assert_lt_as_result!(2, 1);
+/// let a = 2;
+/// let b = 1;
+/// let x = assert_lt_as_result!(a, b);
 /// //-> Err(…)
 /// let actual = x.unwrap_err();
 /// let expect = concat!(
 ///     "assertion failed: `assert_lt!(left, right)`\n",
-///     "  left: `2`,\n",
-///     " right: `1`"
+///     "  left label: `a`,\n",
+///     "  left debug: `2`,\n",
+///     " right label: `b`,\n",
+///     " right debug: `1`,\n",
+///     "        left: `2`,\n",
+///     "       right: `1`"
 /// );
 /// assert_eq!(actual, expect);
 /// # }
@@ -37,7 +45,21 @@ macro_rules! assert_lt_as_result {
                 if a_val < b_val {
                     Ok(())
                 } else {
-                    Err(msg_with_left_and_right!("assertion failed", "assert_lt!", a_val, b_val))
+                    Err(format!(
+                        concat!(
+                            "assertion failed: `assert_lt!(left, right)`\n",
+                            "  left label: `{}`,\n",
+                            "  left debug: `{:?}`,\n",
+                            " right label: `{}`,\n",
+                            " right debug: `{:?}`,\n",
+                            "        left: `{:?}`,\n",
+                            "       right: `{:?}`"
+                        ),
+                        stringify!($a), $a,
+                        stringify!($b), $b,
+                        a_val, 
+                        b_val
+                    ))
                 }
             }
         }
@@ -67,8 +89,12 @@ mod test_assert_x_result {
             x.unwrap_err(),
             concat!(
                 "assertion failed: `assert_lt!(left, right)`\n",
-                "  left: `2`,\n",
-                " right: `1`"
+                "  left label: `a`,\n",
+                "  left debug: `2`,\n",
+                " right label: `b`,\n",
+                " right debug: `1`,\n",
+                "        left: `2`,\n",
+                "       right: `1`"
             )
         );
     }
@@ -76,7 +102,7 @@ mod test_assert_x_result {
 
 /// Assert a value is less than another.
 ///
-/// * When true, return `()`.
+/// * If true, return `()`.
 ///
 /// * Otherwise, call [`panic!`] with a message and the values of the
 ///   expressions with their debug representations.
@@ -87,18 +113,26 @@ mod test_assert_x_result {
 /// # #[macro_use] extern crate assertables;
 /// # use std::panic;
 /// # fn main() {
-/// assert_lt!(1, 2);
+/// let a = 1;
+/// let b = 2;
+/// assert_lt!(a, b);
 /// //-> ()
 ///
 /// let result = panic::catch_unwind(|| {
-/// assert_lt!(2, 1);
+/// let a = 2;
+/// let b = 1;
+/// assert_lt!(a, b);
 /// //-> panic!
 /// });
 /// let actual = result.unwrap_err().downcast::<String>().unwrap().to_string();
 /// let expect = concat!(
 ///     "assertion failed: `assert_lt!(left, right)`\n",
-///     "  left: `2`,\n",
-///     " right: `1`"
+///     "  left label: `a`,\n",
+///     "  left debug: `2`,\n",
+///     " right label: `b`,\n",
+///     " right debug: `1`,\n",
+///     "        left: `2`,\n",
+///     "       right: `1`"
 /// );
 /// assert_eq!(actual, expect);
 /// # }
@@ -119,40 +153,3 @@ macro_rules! assert_lt {
         }
     });
 }
-
-#[cfg(test)]
-mod test_x_panic {
-
-    #[test]
-    fn test_assert_lt_x_arity_2_success() {
-        let a: i32 = 1;
-        let b: i32 = 2;
-        let x = assert_lt!(a, b);
-        assert_eq!(x, ());
-    }
-
-    #[test]
-    #[should_panic (expected = "assertion failed: `assert_lt!(left, right)`\n  left: `2`,\n right: `1`")]
-    fn test_assert_lt_x_arity_2_failure() {
-        let a: i32 = 2;
-        let b: i32 = 1;
-        let _x = assert_lt!(a, b);
-    }
-
-    #[test]
-    fn test_assert_lt_x_arity_3_success() {
-        let a: i32 = 1;
-        let b: i32 = 2;
-        let x = assert_lt!(a, b, "message");
-        assert_eq!(x, ());
-    }
-
-    #[test]
-    #[should_panic (expected = "message")]
-    fn test_assert_lt_x_arity_3_failure() {
-        let a: i32 = 2;
-        let b: i32 = 1;
-        let _x = assert_lt!(a, b, "message");
-    }
-
-}
