@@ -1,6 +1,6 @@
 /// Assert a value is not equal to another.
 ///
-/// * When true, return Result `Ok(())`.
+/// * If true, return Result `Ok(())`.
 ///
 /// * When false, return [`Err`] with a message and the values of the
 ///   expressions with their debug representations.
@@ -11,19 +11,27 @@
 /// # #[macro_use] extern crate assertables;
 /// # use std::panic;
 /// # fn main() {
-/// let x = assert_ne_as_result!(1, 2);
+/// let a = 1;
+/// let b = 2;
+/// let x = assert_ne_as_result!(a, b);
 /// //-> Ok(())
 /// let actual = x.unwrap();
 /// let expect = ();
 /// assert_eq!(actual, expect);
 ///
-/// let x = assert_ne_as_result!(1, 1);
+/// let a = 1;
+/// let b = 1;
+/// let x = assert_ne_as_result!(a, b);
 /// //-> Err(…)
 /// let actual = x.unwrap_err();
 /// let expect = concat!(
 ///     "assertion failed: `assert_ne!(left, right)`\n",
-///     "  left: `1`,\n",
-///     " right: `1`"
+///     "  left label: `a`,\n",
+///     "  left debug: `1`,\n",
+///     " right label: `b`,\n",
+///     " right debug: `1`,\n",
+///     "        left: `1`,\n",
+///     "       right: `1`"
 /// );
 /// assert_eq!(actual, expect);
 /// # }
@@ -37,7 +45,21 @@ macro_rules! assert_ne_as_result {
                 if a_val != b_val {
                     Ok(())
                 } else {
-                    Err(msg_with_left_and_right!("assertion failed", "assert_ne!", a_val, b_val))
+                    Err(format!(
+                        concat!(
+                            "assertion failed: `assert_ne!(left, right)`\n",
+                            "  left label: `{}`,\n",
+                            "  left debug: `{:?}`,\n",
+                            " right label: `{}`,\n",
+                            " right debug: `{:?}`,\n",
+                            "        left: `{:?}`,\n",
+                            "       right: `{:?}`"
+                        ),
+                        stringify!($a), $a,
+                        stringify!($b), $b,
+                        a_val, 
+                        b_val
+                    ))
                 }
             }
         }
@@ -67,78 +89,13 @@ mod test_x_result {
             x.unwrap_err(),
             concat!(
                 "assertion failed: `assert_ne!(left, right)`\n",
-                "  left: `1`,\n",
-                " right: `1`"
+                "  left label: `a`,\n",
+                "  left debug: `1`,\n",
+                " right label: `b`,\n",
+                " right debug: `1`,\n",
+                "        left: `1`,\n",
+                "       right: `1`"
             )
         );
     }
 }
-
-/// Assert a value is not equal to another.
-///
-/// * When true, return `()`.
-///
-/// * When false, call [`panic!`] with a message and the values of the
-///   expressions with their debug representations.
-///
-/// # Examples
-///
-/// ```rust
-/// # #[macro_use] extern crate assertables;
-/// # use std::panic;
-/// # fn main() {
-/// assert_ne!(1, 2);
-/// //-> ()
-///
-/// let result = panic::catch_unwind(|| {
-/// assert_ne!(1, 1);
-/// //-> panic!
-/// });
-/// let actual = result.unwrap_err().downcast::<String>().unwrap().to_string();
-/// let expect = concat!(
-///     "assertion failed: `(left != right)`\n",
-///     "  left: `1`,\n",
-///     " right: `1`"
-/// );
-/// assert_eq!(actual, expect);
-/// # }
-/// ```
-
-// `assert_ne` macro is provided by Rust `std`.
-
-#[cfg(test)]
-mod test_x_panic {
-
-    #[test]
-    fn test_assert_ne_x_arity_2_success() {
-        let a: i32 = 1;
-        let b: i32 = 2;
-        let x = assert_ne!(a, b);
-        assert_eq!(x, ());
-    }
-
-    #[test]
-    #[should_panic (expected = "assertion failed: `(left != right)`\n  left: `1`,\n right: `1`")]
-    fn test_assert_ne_x_arity_2_failure() {
-        let a: i32 = 1;
-        let b: i32 = 1;
-        assert_ne!(a, b);
-    }
-
-    #[test]
-    fn test_assert_ne_x_arity_3_success() {
-        let a: i32 = 1;
-        let b: i32 = 2;
-        let x = assert_ne!(a, b, "message");
-        assert_eq!(x, ());
-    }
-
-    #[test]
-    #[should_panic (expected = "message")]
-    fn test_assert_ne_x_arity_3_failure() {
-        let a: i32 = 1;
-        let b: i32 = 1;
-        assert_ne!(a, b, "message");
-    }
-
-}
