@@ -1,8 +1,8 @@
 /// Assert a a std::io::Read read_to_string() is a match to a given regex.
 ///
-/// * When true, return `()`.
+/// * If true, return Result `Ok(())`.
 ///
-/// * When true, return Result `Err` with a diagnostic message.
+/// * Otherwise, return Result `Err` with a diagnostic message.
 ///
 /// # Examples
 ///
@@ -23,12 +23,13 @@
 /// //-> Err(…)
 /// let actual = x.unwrap_err();
 /// let expect = concat!(
-///     "assertion failed: `assert_read_to_string_matches!(left_reader, right_expr)`\n",
-///     " left reader name: `reader`,\n",
-///     "  right expr name: `matcher`,\n",
-///     " left reader size: `5`,\n",
-///     " left reader data: `\"hello\"`,\n",
-///     "       right expr: `xyz`"
+///     "assertion failed: `assert_read_to_string_matches!(left_reader, right_matcher)`\n",
+///     "   left_reader label: `reader`,\n",
+///     "   left_reader debug: `[]`,\n",
+///     " right_matcher label: `matcher`,\n",
+///     " right_matcher debug: `xyz`,\n",
+///     "                left: `\"hello\"`,\n",
+///     "               right: `xyz`"
 /// );
 /// assert_eq!(actual, expect);
 /// # }
@@ -36,30 +37,42 @@
 ///
 #[macro_export]
 macro_rules! assert_read_to_string_matches_as_result {
-    ($reader:expr, $matcher:expr $(,)?) => ({
+    ($a_reader:expr, $b_matcher:expr $(,)?) => ({
         let mut a_string = String::new();
-        let a_result = $reader.read_to_string(&mut a_string);
+        let a_result = $a_reader.read_to_string(&mut a_string);
         if let Err(a_err) = a_result {
-            Err(msg_with_left_reader_and_right_expr_and_err!(
-                "assertion failed",
-                "assert_read_to_string_matches!",
-                stringify!($reader),
-                stringify!($matcher),
+            Err(format!(
+                concat!(
+                    "assertion failed: `assert_read_to_string_matches!(left_reader, right_matcher)`\n",
+                    "   left_reader label: `{}`,\n",
+                    "   left_reader debug: `{:?}`,\n",
+                    " right_matcher label: `{}`,\n",
+                    " right_matcher debug: `{:?}`,\n",
+                    "            left err: `{:?}`"
+                ),
+                stringify!($a_reader), $a_reader,
+                stringify!($b_matcher), $b_matcher,
                 a_err
             ))
         } else {
-            let a_size = a_result.unwrap();
-            if $matcher.is_match(a_string.as_str()) {
+            let _a_size = a_result.unwrap();
+            if $b_matcher.is_match(a_string.as_str()) {
                 Ok(())
             } else {
-                Err(msg_with_left_reader_and_right_expr!(
-                    "assertion failed",
-                    "assert_read_to_string_matches!",
-                    stringify!($reader),
-                    stringify!($matcher),
-                    a_size,
+                Err(format!(
+                    concat!(
+                        "assertion failed: `assert_read_to_string_matches!(left_reader, right_matcher)`\n",
+                        "   left_reader label: `{}`,\n",
+                        "   left_reader debug: `{:?}`,\n",
+                        " right_matcher label: `{}`,\n",
+                        " right_matcher debug: `{:?}`,\n",
+                        "                left: `{:?}`,\n",
+                        "               right: `{:?}`",
+                    ),
+                    stringify!($a_reader), $a_reader,
+                    stringify!($b_matcher), $b_matcher,
                     a_string,
-                    $matcher
+                    $b_matcher
                 ))
             }
         }
@@ -90,12 +103,13 @@ mod test_x_result {
         assert_eq!(
             x.unwrap_err(),
             concat!(
-                "assertion failed: `assert_read_to_string_matches!(left_reader, right_expr)`\n",
-                " left reader name: `reader`,\n",
-                "  right expr name: `matcher`,\n",
-                " left reader size: `5`,\n",
-                " left reader data: `\"alpha\"`,\n",
-                "       right expr: `xyz`"
+                "assertion failed: `assert_read_to_string_matches!(left_reader, right_matcher)`\n",
+                "   left_reader label: `reader`,\n",
+                "   left_reader debug: `[]`,\n",
+                " right_matcher label: `matcher`,\n",
+                " right_matcher debug: `xyz`,\n",
+                "                left: `\"alpha\"`,\n",
+                "               right: `xyz`"
             )
         );
     }
@@ -103,7 +117,7 @@ mod test_x_result {
 
 /// Assert a a std::io::Read read_to_string() is a match to a given regex.
 ///
-/// * When true, return `()`.
+/// * If true, return `()`.
 ///
 /// * Otherwise, call [`panic!`] with a message and the values of the
 ///   expressions with their debug representations.
@@ -130,12 +144,13 @@ mod test_x_result {
 /// });
 /// let actual = result.unwrap_err().downcast::<String>().unwrap().to_string();
 /// let expect = concat!(
-///     "assertion failed: `assert_read_to_string_matches!(left_reader, right_expr)`\n",
-///     " left reader name: `reader`,\n",
-///     "  right expr name: `matcher`,\n",
-///     " left reader size: `5`,\n",
-///     " left reader data: `\"hello\"`,\n",
-///     "       right expr: `xyz`"
+///     "assertion failed: `assert_read_to_string_matches!(left_reader, right_matcher)`\n",
+///     "   left_reader label: `reader`,\n",
+///     "   left_reader debug: `[]`,\n",
+///     " right_matcher label: `matcher`,\n",
+///     " right_matcher debug: `xyz`,\n",
+///     "                left: `\"hello\"`,\n",
+///     "               right: `xyz`"
 /// );
 /// assert_eq!(actual, expect);
 /// # }
@@ -156,42 +171,3 @@ macro_rules! assert_read_to_string_matches {
         }
     });
 }
-
-#[cfg(test)]
-mod test_x_panic {
-    use std::io::Read;
-    use regex::Regex;
-
-    #[test]
-    fn test_assert_read_to_string_matches_x_arity_2_success() {
-        let mut reader = "alpha".as_bytes();
-        let matcher = Regex::new(r"lph").unwrap();
-        let x = assert_read_to_string_matches!(reader, matcher);
-        assert_eq!(x, ());
-    }
-
-    #[test]
-    #[should_panic (expected = "assertion failed: `assert_read_to_string_matches!(left_reader, right_expr)`\n left reader name: `reader`,\n  right expr name: `matcher`,\n left reader size: `5`,\n left reader data: `\"alpha\"`,\n       right expr: `xyz`")]
-    fn test_assert_read_to_string_matches_x_arity_2_failure() {
-        let mut reader = "alpha".as_bytes();
-        let matcher = Regex::new(r"xyz").unwrap();
-        let _x = assert_read_to_string_matches!(reader, matcher);
-    }
-
-    #[test]
-    fn test_assert_read_to_string_matches_x_arity_3_success() {
-        let mut reader = "alpha".as_bytes();
-        let matcher = Regex::new(r"lph").unwrap();
-        let x = assert_read_to_string_matches!(reader, matcher, "message");
-        assert_eq!(x, ());
-    }
-
-    #[test]
-    #[should_panic (expected = "message")]
-    fn test_assert_read_to_string_matches_x_arity_3_failure() {
-        let mut reader = "alpha".as_bytes();
-        let matcher = Regex::new(r"xyz").unwrap();
-        let _x = assert_read_to_string_matches!(reader, matcher, "message");
-    }
-
-}
