@@ -15,35 +15,35 @@
 //!
 //! ## Highlights
 //!
-//! Value macros:
+//! Value macros such as:
 //!
-//!   * Such as `assert_gt!(value1, value2)`
+//! * `assert_gt!(value1, value2)`
 //!
-//!   * Which means `value1 > value2`
+//! * Means `value1 > value2`
 //!
-//! Set macros:
+//! Set macros such as:
 //!
-//!   * Such as `assert_set_subset!(set1, set2)`
+//! * `assert_set_subset!(set1, set2)`
 //!
-//!   * Which means `set1 ⊆ set2`
+//! * Means `set1 ⊆ set2`
 //!
-//! Function macros:
+//! Function macros such as:
 //!
-//!   * Such as `assert_fn_eq!(function, input, value)`
+//! * `assert_fn_eq!(function, input, output)`
 //!
-//!   * Which means `function(input) == value`
+//! * Means `function(input) == output`
 //!
-//! Reader macros:
+//! Reader macros such as:
 //!
-//!   * Such as `assert_read_to_string_eq!(reader, string)`
+//! * `assert_read_to_string_eq!(reader, string)`
 //!
-//!   * This means `reader1.read_to_string() == string`
+//! * Means `reader.read_to_string() == string`
 //!
-//! Commmand macros:
+//! Commmand macros such as:
 //!
-//!   * Such as `assert_command_stdout_eq!(command, string)`
+//! * `assert_command_stdout_eq!(command, expr)`
 //!
-//!   * This means `String::from_utf8(command.output().unwrap().stdout).unwrap() == string`
+//! * Means `String::from_utf8(command.output().unwrap().stdout).unwrap() == expr`
 //!
 //!
 //! ## Naming conventions
@@ -58,24 +58,24 @@
 //!
 //! Shorthands:
 //!
-//!   * `reader` means implements `.read_to_string(…)` such as `std::io::Read`.
+//! * `reader` means implements `.read_to_string(…)` such as `std::io::Read`.
 //!
-//!   * `matcher` means implements `.is_match(…)` such as `regex::Regex`.
+//! * `matcher` means implements `.is_match(…)` such as `regex::Regex`.
 //!
-//!   * `containee` means usable inside `.contains(…)` such as a `std::string::String` substring.
+//! * `containee` means usable inside `.contains(…)` such as a `std::string::String` substring.
 //!
-//!   * `set` means a collection such as `::std::collections::BTreeSet`.
+//! * `set` means a collection such as `::std::collections::BTreeSet`.
 //!
-//!   * `bag` means a collection such as `::std::collections::BTreeMap` with key counts.
+//! * `bag` means a collection such as `::std::collections::BTreeMap` with key counts.
 //!
 //!
 //! ## Forms for panic! versus Err()
 //!
 //! The macros have two forms, for immediate interrupts versus returning results:
 //!
-//!    * `assert_gt!(a, b)` => `()` or `panic!(…)`
+//! * `assert_gt!(a, b)` => `()` or `panic!(…)`
 //!
-//!    * `assert_gt_as_result!(a, b)` => `Result Ok(())` or `Result Err(…)`
+//! * `assert_gt_as_result!(a, b)` => `Result Ok(())` or `Result Err(…)`
 //!
 //!
 //! ## Forms for default messages versus custom messages
@@ -84,9 +84,9 @@
 //!
 //! Example:
 //!
-//!    * `assert_gt(1, 2)` => `panic!("assertion failed: `assert_gt(1, 2)`…")`
+//! * `assert_gt(1, 2)` => `panic!("assertion failed: assert_gt(1, 2)…")`
 //!
-//!    * `assert_gt(1, 2, "lorem ipsum")` => `panic!("lorem ipsum")`
+//! * `assert_gt(1, 2, "lorem ipsum")` => `panic!("lorem ipsum")`
 //!
 //!
 //! ## Forms for comparing an expression versus equivalent
@@ -95,9 +95,9 @@
 //!
 //! Example:
 //!
-//!    * `assert_read_to_string_eq!(reader, expr)` => `reader.read_to_string() == expr`
+//! * `assert_read_to_string_eq!(reader, expr)` => `reader.read_to_string() == expr`
 //!
-//!    * `assert_read_to_string_eq_other!(reader1, reader2)` => `reader1.read_to_string() == reader2.read_to_string()`
+//! * `assert_read_to_string_eq_other!(reader1, reader2)` => `reader1.read_to_string() == reader2.read_to_string()`
 //!
 //!
 //! ## assert_* for values
@@ -272,7 +272,7 @@
 //!
 //! * `assert_command_stdout_contains!(command, containee)` ~ String::from_utf8(command.output().unwrap().stdout).unwrap().contains(containee)
 //!
-//! * `assert_command_stdout_matches!(command, matcher)` ~ regex.captures(String::from_utf8(command.output().unwrap().stdout).unwrap())
+//! * `assert_command_stdout_matches!(command, matcher)` ~ regex.is_match(String::from_utf8(command.output().unwrap().stdout).unwrap())
 //!
 //! Using standard error a.k.a. stderr:
 //!
@@ -282,33 +282,17 @@
 //!
 //! * `assert_command_stderr_contains!(command, containee)` ~ String::from_utf8(command.output().unwrap().stderr).unwrap().contains(containee)
 //!
-//! * `assert_command_stderr_matches!(command, matcher)` ~ regex.captures(String::from_utf8(command.output().unwrap().stderr).unwrap())
+//! * `assert_command_stderr_matches!(command, matcher)` ~ regex.is_match(String::from_utf8(command.output().unwrap().stderr).unwrap())
 //!
 //!
 //! ## Tracking
 //!
 //! * Package: assertables-rust-crate
-//! * Version: 5.0.0
+//! * Version: 5.1.0
 //! * Created: 2021-03-30T15:47:49Z
-//! * Updated: 2022-02-28T15:45:38Z
-//! * License: GPL-2.0-or-later or contact us for custom license
+//! * Updated: 2022-04-11T11:22:18Z
+//! * License: MIT or Apache-2.0 or GPL-2.0 or contact us for custom license
 //! * Contact: Joel Parker Henderson (joel@sixarm.com)
-//!
-
-// Message macros such as for panic!(…) and Err(…).
-#[macro_use] mod msg_with_left_and_right;
-
-// Message macros for commands
-#[macro_use] mod msg_with_left_command_and_right_command;
-#[macro_use] mod msg_with_left_command_and_right_expr;
-
-// Message macros for functions
-#[macro_use] mod msg_with_pair_function_and_left_input_and_right_input;
-#[macro_use] mod msg_with_left_function_and_left_input_and_right_expr;
-
-// Message macros for readers
-#[macro_use] mod msg_with_left_reader_and_right_reader;
-#[macro_use] mod msg_with_left_reader_and_right_expr;
 
 // Assert truth
 pub mod assert; // (provided by Rust `std`)
@@ -407,6 +391,6 @@ pub mod assert_command_stdout_matches;
 pub mod assert_command_stderr_eq;
 pub mod assert_command_stderr_eq_other;
 
-// Assert command stdett specializations
+// Assert command stderr specializations
 pub mod assert_command_stderr_contains;
 pub mod assert_command_stderr_matches;
